Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1375)

Unified Diff: Source/core/loader/FrameLoader.cpp

Issue 980213002: Rename InsecureContentPolicy to InsecureRequestsPolicy. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/loader/FrameLoader.h ('k') | Source/modules/websockets/DOMWebSocket.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/loader/FrameLoader.cpp
diff --git a/Source/core/loader/FrameLoader.cpp b/Source/core/loader/FrameLoader.cpp
index 65497cf1c2506e975077e69f485e77df01637399..03a988189bcfd302f5f3a83228627767d21945bb 100644
--- a/Source/core/loader/FrameLoader.cpp
+++ b/Source/core/loader/FrameLoader.cpp
@@ -1401,18 +1401,18 @@ bool FrameLoader::shouldEnforceStrictMixedContentChecking() const
return toLocalFrame(parentFrame)->document()->shouldEnforceStrictMixedContentChecking();
}
-SecurityContext::InsecureContentPolicy FrameLoader::insecureContentPolicy() const
+SecurityContext::InsecureRequestsPolicy FrameLoader::insecureRequestsPolicy() const
{
Frame* parentFrame = m_frame->tree().parent();
if (!parentFrame)
- return SecurityContext::InsecureContentDoNotUpgrade;
+ return SecurityContext::InsecureRequestsDoNotUpgrade;
- // FIXME: We need a way to propagate insecure content policy flags to
+ // FIXME: We need a way to propagate insecure requests policy flags to
// out-of-process frames. For now, we'll always use default behavior.
if (!parentFrame->isLocalFrame())
- return SecurityContext::InsecureContentDoNotUpgrade;
+ return SecurityContext::InsecureRequestsDoNotUpgrade;
- return toLocalFrame(parentFrame)->document()->insecureContentPolicy();
+ return toLocalFrame(parentFrame)->document()->insecureRequestsPolicy();
}
} // namespace blink
« no previous file with comments | « Source/core/loader/FrameLoader.h ('k') | Source/modules/websockets/DOMWebSocket.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698